==> spm_python-25.1b1.post4.tar.gz: spm_python-25.1b1.post4/spm/__matlabbatch/cfg_const.py <==
from mpython import Runtime, MatlabClass


class cfg_const(MatlabClass):
    def __init__(self, *args, **kwargs):
        """
          This is the const configuration item class

            Data structure
            ==============
            Description fields
               * name  - display name of config item
               * tag   - tag of the menu item
               * val   - 1x1 cell array
               * check - (optional) function handle to implement configuration
                         specific subsasgn checks. This is not used here, since a
                         const should not change.
               * help  - help text
            GUI/job manager fields
               * expanded
               * hidden
            All fields are inherited from the generic configuration item class.

            Public Methods
            ==============
               * get_strings - returns name of object
               * gettag      - returns tag
               * help        - returns help text
               * harvest
               * all_set

            * 'const' - Constant value
              - required fields: 'type', 'name', 'tag', 'val'
              - optional fields: 'help'

              The resulting data structure simply contains the contents of
              val{1}.

            The layout of the configuration tree and the types of configuration items
            have been kept compatible to a configuration system and job manager
            implementation in SPM5 (Statistical Parametric Mapping, Copyright (C)
            2005 Wellcome Department of Imaging Neuroscience). This code has been
            completely rewritten based on an object oriented model of the
            configuration tree.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging

              Documentation for cfg_const
                 doc cfg_const



        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/cfg_const.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        super().__init__()

    def cfg2struct(self, *args, **kwargs):
        """
          function sitem = cfg2struct(item)
            Return a struct containing all fields of item plus a field type. This is
            the method suitable for entry classes.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/cfg2struct.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("cfg2struct", self._as_matlab_object(), *args, **kwargs)

    def showdetail(self, *args, **kwargs):
        """
          function str = showdetail(item)
            Display details for a cfg_const item.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/showdetail.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("showdetail", self._as_matlab_object(), *args, **kwargs)

    def showdoc(self, *args, **kwargs):
        """
          function str = showdoc(item, indent)
            Display help text for a cfg_const item.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/showdoc.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("showdoc", self._as_matlab_object(), *args, **kwargs)

    def subs_fields(self, *args, **kwargs):
        """
          function fnames = subs_fields(item)
            This function works as a "class-based switch" to return the value of
            the private mysubs_fields function for the appropriate class.
            This function is identical for all classes derived from cfg_item, but
            it has to be in the class directory to access the proper private
            function mysubs_fields.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/subs_fields.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("subs_fields", self._as_matlab_object(), *args, **kwargs)

    def subsasgn(self, *args, **kwargs):
        """
          function item = subsasgn(item, subs, varargin)
            This function implements subsasgn for all classes derived from cfg_item.
            It relies on the capability of each class constructor to re-classify a
            struct object after a new value has been assigned to its underlying
            struct (This capability has to be implemented in the derived class).
            The structure of a configuration tree does not permit any arrays of
            cfg_item objects. Therefore, the only subscript reference and
            assignment within an cfg_item is a dot assignment to fields of this
            cfg_item.
            Subscript references we have to deal with are:
            one level
            item.(field)   - i.e. struct('type',{'.'} ,'subs',{field})

            to be dealt with elsewhere
            item.(field){fidx}

            In a future version, '()' and '{}' subscripts may be supported to
            access val fields of a cfg_item tree as if they were part of a
            harvested job. For cfg_branch objects (where dot assignments are used
            for val fields in their job tree) it is mandatory to index the job as a
            struct array to access harvested fields.
            This function is identical for all classes derived from cfg_item. A
            copy of it must be present in each derived class to be able to access
            derived fields.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/subsasgn.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("subsasgn", self._as_matlab_object(), *args, **kwargs)

    def subsref(self, *args, **kwargs):
        """
          function varargout = subsref(item, subs)
            subscript references we have to deal with are:
            one level
            item.(field)   - i.e. struct('type',{'.'} ,'subs',{field})
            item(idx)      - i.e. struct('type',{'()'},'subs',{idx})
            two levels
            item(idx).(field)

            to be dealt with elsewhere
            item.(field){fidx}
            three levels
            item(idx).(field){fidx}
            This function is identical for all classes derived from cfg_item, but it
            needs to be present in the class folder to access fields added by the
            derived class.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/subsref.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("subsref", self._as_matlab_object(), *args, **kwargs)

    def _mysubs_fields(self, *args, **kwargs):
        """
          function [fnames, defaults] = mysubs_fields
            Additional fields for class cfg_const. See help of
            @cfg_item/subs_fields for general help about this function.

            This code is part of a batch job configuration system for MATLAB. See
                 help matlabbatch
            for a general overview.
           _______________________________________________________________________
            Copyright (C) 2007 Freiburg Brain Imaging


        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/private/mysubs_fields.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """
        return Runtime.call("mysubs_fields", self._as_matlab_object(), *args, **kwargs)

==> spm_python-25.1.2.post2.tar.gz: spm_python-25.1.2.post2/spm/__matlabbatch/cfg_const.py <==
from mpython import MatlabClass
from spm._runtime import Runtime, RuntimeMixin


class cfg_const(RuntimeMixin, MatlabClass):
    def __init__(self, *args, **kwargs):
        """
          This is the const configuration item class  
             
            Data structure  
            ==============  
            Description fields  
               * name  - display name of config item  
               * tag   - tag of the menu item  
               * val   - 1x1 cell array  
               * check - (optional) function handle to implement configuration  
                         specific subsasgn checks. This is not used here, since a  
                         const should not change.  
               * help  - help text  
            GUI/job manager fields  
               * expanded  
               * hidden  
            All fields are inherited from the generic configuration item class.  
             
            Public Methods  
            ==============  
               * get_strings - returns name of object  
               * gettag      - returns tag  
               * help        - returns help text  
               * harvest  
               * all_set  
             
            * 'const' - Constant value  
              - required fields: 'type', 'name', 'tag', 'val'  
              - optional fields: 'help'  
             
              The resulting data structure simply contains the contents of  
              val{1}.  
             
            The layout of the configuration tree and the types of configuration items  
            have been kept compatible to a configuration system and job manager  
            implementation in SPM5 (Statistical Parametric Mapping, Copyright (C)  
            2005 Wellcome Department of Imaging Neuroscience). This code has been  
            completely rewritten based on an object oriented model of the  
            configuration tree.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
            
              Documentation for cfg_const  
                 doc cfg_const  
            
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/cfg_const.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        super().__init__()

    def cfg2struct(self, *args, **kwargs):
        """
          function sitem = cfg2struct(item)  
            Return a struct containing all fields of item plus a field type. This is  
            the method suitable for entry classes.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/cfg2struct.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("cfg2struct", self._as_matlab_object(), *args, **kwargs)

    def showdetail(self, *args, **kwargs):
        """
          function str = showdetail(item)  
            Display details for a cfg_const item.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/showdetail.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("showdetail", self._as_matlab_object(), *args, **kwargs)

    def showdoc(self, *args, **kwargs):
        """
          function str = showdoc(item, indent)  
            Display help text for a cfg_const item.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/showdoc.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("showdoc", self._as_matlab_object(), *args, **kwargs)

    def subs_fields(self, *args, **kwargs):
        """
          function fnames = subs_fields(item)  
            This function works as a "class-based switch" to return the value of  
            the private mysubs_fields function for the appropriate class.   
            This function is identical for all classes derived from cfg_item, but  
            it has to be in the class directory to access the proper private  
            function mysubs_fields.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/subs_fields.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("subs_fields", self._as_matlab_object(), *args, **kwargs)

    def subsasgn(self, *args, **kwargs):
        """
          function item = subsasgn(item, subs, varargin)  
            This function implements subsasgn for all classes derived from cfg_item.  
            It relies on the capability of each class constructor to re-classify a  
            struct object after a new value has been assigned to its underlying  
            struct (This capability has to be implemented in the derived class).  
            The structure of a configuration tree does not permit any arrays of  
            cfg_item objects. Therefore, the only subscript reference and  
            assignment within an cfg_item is a dot assignment to fields of this  
            cfg_item.   
            Subscript references we have to deal with are:  
            one level  
            item.(field)   - i.e. struct('type',{'.'} ,'subs',{field})  
             
            to be dealt with elsewhere  
            item.(field){fidx}  
              
            In a future version, '()' and '{}' subscripts may be supported to  
            access val fields of a cfg_item tree as if they were part of a  
            harvested job. For cfg_branch objects (where dot assignments are used  
            for val fields in their job tree) it is mandatory to index the job as a  
            struct array to access harvested fields.  
            This function is identical for all classes derived from cfg_item. A  
            copy of it must be present in each derived class to be able to access  
            derived fields.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/subsasgn.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("subsasgn", self._as_matlab_object(), *args, **kwargs)

    def subsref(self, *args, **kwargs):
        """
          function varargout = subsref(item, subs)  
            subscript references we have to deal with are:  
            one level  
            item.(field)   - i.e. struct('type',{'.'} ,'subs',{field})  
            item(idx)      - i.e. struct('type',{'()'},'subs',{idx})  
            two levels  
            item(idx).(field)  
             
            to be dealt with elsewhere  
            item.(field){fidx}  
            three levels  
            item(idx).(field){fidx}  
            This function is identical for all classes derived from cfg_item, but it  
            needs to be present in the class folder to access fields added by the  
            derived class.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/subsref.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("subsref", self._as_matlab_object(), *args, **kwargs)

    def _mysubs_fields(self, *args, **kwargs):
        """
          function [fnames, defaults] = mysubs_fields  
            Additional fields for class cfg_const. See help of  
            @cfg_item/subs_fields for general help about this function.  
             
            This code is part of a batch job configuration system for MATLAB. See   
                 help matlabbatch  
            for a general overview.  
           _______________________________________________________________________  
            Copyright (C) 2007 Freiburg Brain Imaging  
          

        [Matlab code]( https://github.com/spm/spm/blob/main/matlabbatch/@cfg_const/private/mysubs_fields.m )

        Copyright (C) 1995-2025 Functional Imaging Laboratory, Department of Imaging Neuroscience, UCL
        """

        return Runtime.call("mysubs_fields", self._as_matlab_object(), *args, **kwargs)
